==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/27/27af4eff7db9214ecf60f69126f05a08.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PageBundle/Model/Tracking404Model.php */
class __TwigTemplate_fb675bc44de22a6fbd5e9096b998edac extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\PageBundle\\Model;

use Mautic\\CoreBundle\\Helper\\CoreParametersHelper;
use Mautic\\LeadBundle\\Tracker\\ContactTracker;
use Mautic\\PageBundle\\Entity\\Page;
use Mautic\\PageBundle\\Entity\\Redirect;
use Symfony\\Component\\HttpFoundation\\Request;

class Tracking404Model
{
    public function __construct(
        private CoreParametersHelper \$coreParametersHelper,
        private ContactTracker \$contactTracker,
        private PageModel \$pageModel
    ) {
    }

    /**
     * @param Page|Redirect \$entity
     *
     * @throws \\Exception
     */
    public function hitPage(\$entity, Request \$request): void
    {
        \$this->pageModel->hitPage(\$entity, \$request, 404);
    }

    public function isTrackable(): bool
    {
        if (!\$this->coreParametersHelper->get('do_not_track_404_anonymous')) {
            return true;
        }
        // already tracked and identified contact
        if (\$lead = \$this->contactTracker->getContactByTrackedDevice()) {
            if (!\$lead->isAnonymous()) {
                return true;
            }
        }

        return false;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PageBundle/Model/Tracking404Model.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PageBundle/Model/Tracking404Model.php", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Model/Tracking404Model.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/27/27af4eff7db9214ecf60f69126f05a08.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PageBundle/Model/Tracking404Model.php */
class __TwigTemplate_fb675bc44de22a6fbd5e9096b998edac extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\PageBundle\\Model;

use Mautic\\CoreBundle\\Helper\\CoreParametersHelper;
use Mautic\\LeadBundle\\Tracker\\ContactTracker;
use Mautic\\PageBundle\\Entity\\Page;
use Mautic\\PageBundle\\Entity\\Redirect;
use Symfony\\Component\\HttpFoundation\\Request;

class Tracking404Model
{
    public function __construct(
        private CoreParametersHelper \$coreParametersHelper,
        private ContactTracker \$contactTracker,
        private PageModel \$pageModel
    ) {
    }

    /**
     * @param Page|Redirect \$entity
     *
     * @throws \\Exception
     */
    public function hitPage(\$entity, Request \$request): void
    {
        \$this->pageModel->hitPage(\$entity, \$request, 404);
    }

    public function isTrackable(): bool
    {
        if (!\$this->coreParametersHelper->get('do_not_track_404_anonymous')) {
            return true;
        }
        // already tracked and identified contact
        if (\$lead = \$this->contactTracker->getContactByTrackedDevice()) {
            if (!\$lead->isAnonymous()) {
                return true;
            }
        }

        return false;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PageBundle/Model/Tracking404Model.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PageBundle/Model/Tracking404Model.php", "/var/www/html/production-demo/app/bundles/PageBundle/Model/Tracking404Model.php");
    }
}
